==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/resolver/impl/$DataCenterEventVariableQueryResolver.java <==
package io.growing.graphql.resolver.impl;

import com.kobylynskyi.graphql.codegen.extension.GrowingIOConfig;
import com.kobylynskyi.graphql.codegen.extension.utils.JavaCollectionUtils;
import com.kobylynskyi.graphql.codegen.extension.utils.OkHttpUtils;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLRequest;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import io.growing.graphql.resolver.*;
import io.growing.graphql.model.*;

/**
 * 通过 id 获取数据中心的事件变量
 */
@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:58+0800"
)
final public class $DataCenterEventVariableQueryResolver implements DataCenterEventVariableQueryResolver {

    private GrowingIOConfig growingIOConfig;

    public $DataCenterEventVariableQueryResolver(GrowingIOConfig growingIOConfig) {
        this.growingIOConfig = growingIOConfig;
    }

    private $DataCenterEventVariableQueryResolver() {}

    /**
     * 通过 id 获取数据中心的事件变量
     */
    @Override
    public EventVariableDto dataCenterEventVariable(String id) throws Exception {
        DataCenterEventVariableQueryRequest request = new DataCenterEventVariableQueryRequest();
        List<String> keys = Arrays.asList("id");
        List<?> values = Arrays.asList(id);
        Map<String, ?> parameters = JavaCollectionUtils.listToMap(keys, values);
        request.getInput().putAll(parameters);
        EventVariableResponseProjection projection = new EventVariableResponseProjection().all$(growingIOConfig.getResponseProjectionMaxDepth());
        GraphQLRequest graphQLRequest = new GraphQLRequest(request, projection);
        DataCenterEventVariableQueryResponse result = OkHttpUtils.executeGraphQLRemote(growingIOConfig, graphQLRequest, DataCenterEventVariableQueryResponse.class);
        return result.dataCenterEventVariable();
    }

}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/resolver/impl/$DataCenterEventVariableQueryResolver.java <==
package io.growing.graphql.resolver.impl;

import com.kobylynskyi.graphql.codegen.extension.GrowingIOConfig;
import com.kobylynskyi.graphql.codegen.extension.utils.JavaCollectionUtils;
import com.kobylynskyi.graphql.codegen.extension.utils.OkHttpUtils;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLRequest;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import io.growing.graphql.resolver.*;
import io.growing.graphql.model.*;

/**
 * 通过 id 获取数据中心的事件变量
 */
@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
final public class $DataCenterEventVariableQueryResolver implements DataCenterEventVariableQueryResolver {

    private GrowingIOConfig growingIOConfig;

    public $DataCenterEventVariableQueryResolver(GrowingIOConfig growingIOConfig) {
        this.growingIOConfig = growingIOConfig;
    }

    private $DataCenterEventVariableQueryResolver() {}

    /**
     * 通过 id 获取数据中心的事件变量
     */
    @Override
    public EventVariableDto dataCenterEventVariable(String id) throws Exception {
        DataCenterEventVariableQueryRequest request = new DataCenterEventVariableQueryRequest();
        List<String> keys = Arrays.asList("id");
        List<?> values = Arrays.asList(id);
        Map<String, ?> parameters = JavaCollectionUtils.listToMap(keys, values);
        request.getInput().putAll(parameters);
        EventVariableResponseProjection projection = new EventVariableResponseProjection().all$(growingIOConfig.getResponseProjectionMaxDepth());
        GraphQLRequest graphQLRequest = new GraphQLRequest(request, projection);
        DataCenterEventVariableQueryResponse result = OkHttpUtils.executeGraphQLRemote(growingIOConfig, graphQLRequest, DataCenterEventVariableQueryResponse.class);
        return result.dataCenterEventVariable();
    }

}
